==> externalVector_1.0.3.tar.gz: externalVector/R/matrixIndex.R <==
setClass("matrixIndex",
         representation(row="vectorIndex",
                        col="vectorIndex",
                        origdim="integer",
                        Names="vectorNamesType"),
         contains="externalVector",
         prototype=list(origdim=as.integer(c(0, 0))))

setMethod("any.na",
          signature(x="matrixIndex"),
          function (x) 
      {
          any.na(x@row) || any.na(x@col)
      })

setMethod("all.na",
          signature(x="matrixIndex"),
          function (x) 
      {
          all.na(x@row) && all.na(x@col)
      })

setMethod("length",
          signature(x = "matrixIndex"),
          function (x) 
      {
          as.integer(length(x@row)*length(x@col))
      })

setMethod("names",
          signature(x="matrixIndex"),
          function (x) x@Names)

setMethod("setNames",
          signature(object = "matrixIndex"),
          function (object, nm) 
      {
          object@Names <- nm
          object
      })

setMethod("dim",
          signature(x = "matrixIndex"),
          function (x) 
      {
          as.integer(c(length(x@row), length(x@col)))
      })

setReplaceMethod("dim",
                 signature(x = "noneIndex"),
                 function (x, value) 
             {
                 value <- as.integer(value)
                 if (length(value) == 0)
                     x
                 else if (length(value) != 2 || prod(value) != 0)
                     stop("invalid dimension")
                 else {
                     m <- value[1]
                     n <- value[2]
                     origdim <- c(m, n)
                     new("matrixIndex",
                         row = if (m == 0)
                         new("noneIndex")
                         else makeSlice(0, m, 1),
                         col = if (n == 0) new("noneIndex")
                         else makeSlice(0, n, 1),
                         origdim = origdim)
                 }
             })

setReplaceMethod("dim",
                 signature(x = "allIndex"),
                 function (x, value) 
             {
                 value <- as.integer(value)
                 if (length(value) == 0)
                     x
                 else if (length(value) != 2 || prod(value) < 0)
                     stop("invalid dimension")
                 else {
                     m <- value[1]
                     n <- value[2]
                     new("matrixIndex",
                         row = if (m == 0)
                         new("noneIndex")
                         else makeSlice(0, m, 1),
                         col = if (n == 0)
                         new("noneIndex")
                         else makeSlice(0, n, 1),
                         origdim = value)
                 }
             })

setReplaceMethod("dim",
                 signature(x = "NAIndex"),
                 function (x, value) 
             {
                 value <- as.integer(value)
                 if (length(value) == 0)
                     x
                 else if (length(value) != 2 || prod(value) != length(x))
                     stop("invalid dimension")
                 else {
                     m <- value[1]
                     n <- value[2]
                     new("matrixIndex",
                         row = if (m == 0)
                         new("noneIndex")
                         else new("NAIndex", Length=m),
                         col = if (n == 0)
                         new("noneIndex")
                         else new("NAIndex", Length=n),
                         origdim = value)
                 }
             })

setReplaceMethod("dim",
                 signature(x = "sliceIndex"),
                 function (x, value) 
             {
                 value <- as.integer(value)
                 if (length(value) == 0)
                     x
                 else if (length(value) != 2 || prod(value) !=
                          length(x) || x@content[3] != 1)
                     stop("invalid dimension")
                 else {
                     m <- value[1]
                     n <- value[2]
                     start <- x@content[1]
                     new("matrixIndex",
                         row = if (m == 0)
                         new("noneIndex")
                         else makeSlice(start %% m,
                                        m, 1),
                         col = if (n == 0)
                         new("noneIndex")
                         else makeSlice(start / m,
                                        n, 1),
                         origdim = value)
                 }
             })

setReplaceMethod("dim",
                 signature(x = "positiveIndex"),
                 function (x, value) 
             {
                 x <- as(x, "sliceIndex")
                 dim(x) <- value
                 x
             })

setMethod("dimnames",
          signature(x = "matrixIndex"),
          function (x) 
      {
          nm1 <- names(x@row)
          nm2 <- names(x@col)
          if (is.null(nm1) && is.null(nm2))
              NULL
          else list(nm1, nm2)
      })

setMethod("setDimNames",
          signature(object = "matrixIndex"),
          function (object, dnm) 
      {
          if (is.null(dnm)) {
              names(object@row) <- NULL
              names(object@col) <- NULL
          } else {
              if (!is.null(dnm[[1]]))
                  names(object@row) <- dnm[[1]]
              if (!is.null(dnm[[2]]))
                  names(object@col) <- dnm[[2]]
          }
          object
      })

setMethod("[[",
          signature(x = "matrixIndex", i = "numeric", j = "missing"),
          function (x, i, j, ...) 
      {
          i <- as.integer(i)
          if (i == 1)
              x@row
          else if (i == 2)
              x@col
          else NULL
      })

setMethod("[",
          signature(x = "matrixIndex"),
          function (x, i, j, ..., drop) 
      {
          if (missing(drop)) {
              drop <- FALSE
              nsubs <- nargs() - 1
          } else {
              nsubs <- nargs() - 2
          }
          if (nsubs == 0)
              nsubs <- 1
          if (nsubs == 1 && missing(i))
              return(x)
          subs <-
              if (nsubs == 1) {
                  alist(i=)
              } else if (nsubs == 2) {
                  alist(i=, j=)
              } else {
                  alist(i=, j=, ...)
              }
          if (!missing(i))
              subs$i <- i
          if (!missing(j))
              subs$j <- j
          subs <- SubscriptList(subs, length(x), dim(x),
                                x@Names, dimnames(x), FALSE)
          n <- x@origdim[1]
          if (length(subs) == 1) {
              nm <- x@Names
              x <- .Call('matrixToVectorIndex', x@row, length(x@row),
                         x@col, length(x@col), x@origdim,
                         subs[[1]], length(subs[[1]]),
                         PACKAGE='externalVector')
              if (length(nm) > 0)
                  names(x) <- Subset(nm, x)
              x
          } else {
              x@row <- x@row[subs[[1]]]
              x@col <- x@col[subs[[2]]]
              if (drop &&
                  (length(x@row) == 1 || length(x@col) == 1)) {
                  if (length(x@row) == 1) {
                      if (length(x@col) == 1)
                          as(x@row[1]+n*x@col[1], 'positiveIndex')
                      else x@row[1]+n*x@col
                  } else x@row+n*x@col[1]
              } else {
                  x@Names <- NULL
                  x
              }
          }
      })

setAs("matrixIndex", "vectorIndex",
      function(from, to)
  {
      ans <- .Call('matrixToVectorIndex', from@row, length(from@row),
                   from@col, length(from@col), from@origdim,
                   new("allIndex"), length(from),
                   PACKAGE='externalVector')
      if (!is.null(names(from)))
          names(ans) <- from
      ans
  })

setMethod("Subset",
          signature(i="matrixIndex"),
          function (x, i) 
      {
          dim(x) <- i@origdim
          Subset2(x, i@row, i@col)
      })

==> externalVector_1.4.0.tar.gz: externalVector/R/matrixIndex.R <==
setClass("matrixIndex",
         representation(row="vectorIndex",
                        col="vectorIndex",
                        origdim="integer",
                        Names="vectorNamesType"),
         contains="externalVector",
         prototype=list(origdim=as.integer(c(0, 0))))

setMethod("anyNA",
          signature(x="matrixIndex"),
          function (x)
      {
          anyNA(x@row) || anyNA(x@col)
      })

setMethod("allNA",
          signature(x="matrixIndex"),
          function (x)
      {
          allNA(x@row) && allNA(x@col)
      })

setMethod("length",
          signature(x = "matrixIndex"),
          function (x)
      {
          as.integer(length(x@row)*length(x@col))
      })

setMethod("names",
          signature(x="matrixIndex"),
          function (x) x@Names)

setMethod("setNames",
          signature(object = "matrixIndex"),
          function (object, nm)
      {
          object@Names <- nm
          object
      })

setMethod("dim",
          signature(x = "matrixIndex"),
          function (x)
      {
          as.integer(c(length(x@row), length(x@col)))
      })

setReplaceMethod("dim",
                 signature(x = "noneIndex"),
                 function (x, value)
             {
                 value <- as.integer(value)
                 if (length(value) == 0)
                     x
                 else if (length(value) != 2 || prod(value) != 0)
                     stop("invalid dimension")
                 else {
                     m <- value[1]
                     n <- value[2]
                     origdim <- c(m, n)
                     new("matrixIndex",
                         row = if (m == 0)
                         new("noneIndex")
                         else makeSlice(0, m, 1),
                         col = if (n == 0) new("noneIndex")
                         else makeSlice(0, n, 1),
                         origdim = origdim)
                 }
             })

setReplaceMethod("dim",
                 signature(x = "allIndex"),
                 function (x, value)
             {
                 value <- as.integer(value)
                 if (length(value) == 0)
                     x
                 else if (length(value) != 2 || prod(value) < 0)
                     stop("invalid dimension")
                 else {
                     m <- value[1]
                     n <- value[2]
                     new("matrixIndex",
                         row = if (m == 0)
                         new("noneIndex")
                         else makeSlice(0, m, 1),
                         col = if (n == 0)
                         new("noneIndex")
                         else makeSlice(0, n, 1),
                         origdim = value)
                 }
             })

setReplaceMethod("dim",
                 signature(x = "NAIndex"),
                 function (x, value)
             {
                 value <- as.integer(value)
                 if (length(value) == 0)
                     x
                 else if (length(value) != 2 || prod(value) != length(x))
                     stop("invalid dimension")
                 else {
                     m <- value[1]
                     n <- value[2]
                     new("matrixIndex",
                         row = if (m == 0)
                         new("noneIndex")
                         else new("NAIndex", Length=m),
                         col = if (n == 0)
                         new("noneIndex")
                         else new("NAIndex", Length=n),
                         origdim = value)
                 }
             })

setReplaceMethod("dim",
                 signature(x = "sliceIndex"),
                 function (x, value)
             {
                 value <- as.integer(value)
                 if (length(value) == 0)
                     x
                 else if (length(value) != 2 || prod(value) !=
                          length(x) || x@content[3] != 1)
                     stop("invalid dimension")
                 else {
                     m <- value[1]
                     n <- value[2]
                     start <- x@content[1]
                     new("matrixIndex",
                         row = if (m == 0)
                         new("noneIndex")
                         else makeSlice(start %% m,
                                        m, 1),
                         col = if (n == 0)
                         new("noneIndex")
                         else makeSlice(start / m,
                                        n, 1),
                         origdim = value)
                 }
             })

setReplaceMethod("dim",
                 signature(x = "positiveIndex"),
                 function (x, value)
             {
                 x <- as(x, "sliceIndex")
                 dim(x) <- value
                 x
             })

setMethod("dimnames",
          signature(x = "matrixIndex"),
          function (x)
      {
          nm1 <- names(x@row)
          nm2 <- names(x@col)
          if (is.null(nm1) && is.null(nm2))
              NULL
          else list(nm1, nm2)
      })

setMethod("setDimNames",
          signature(object = "matrixIndex"),
          function (object, dnm)
      {
          if (is.null(dnm)) {
              names(object@row) <- NULL
              names(object@col) <- NULL
          } else {
              if (!is.null(dnm[[1]]))
                  names(object@row) <- dnm[[1]]
              if (!is.null(dnm[[2]]))
                  names(object@col) <- dnm[[2]]
          }
          object
      })

setMethod("[[",
          signature(x = "matrixIndex", i = "numeric", j = "missing"),
          function (x, i, j, ...)
      {
          i <- as.integer(i)
          if (i == 1)
              x@row
          else if (i == 2)
              x@col
          else NULL
      })

setMethod("[",
          signature(x = "matrixIndex"),
          function (x, i, j, ..., drop)
      {
          if (missing(drop)) {
              drop <- FALSE
              nsubs <- nargs() - 1
          } else {
              nsubs <- nargs() - 2
          }
          if (nsubs == 0)
              nsubs <- 1
          if (nsubs == 1 && missing(i))
              return(x)
          subs <-
              if (nsubs == 1) {
                  alist(i=)
              } else if (nsubs == 2) {
                  alist(i=, j=)
              } else {
                  alist(i=, j=, ...)
              }
          if (!missing(i))
              subs$i <- i
          if (!missing(j))
              subs$j <- j
          subs <- SubscriptList(subs, length(x), dim(x),
                                x@Names, dimnames(x), FALSE)
          n <- x@origdim[1]
          if (length(subs) == 1) {
              nm <- x@Names
              x <- .Call('matrixToVectorIndex', x@row, length(x@row),
                         x@col, length(x@col), x@origdim,
                         subs[[1]], length(subs[[1]]),
                         PACKAGE='externalVector')
              if (length(nm) > 0)
                  names(x) <- Subset(nm, x)
              x
          } else {
              x@row <- x@row[subs[[1]]]
              x@col <- x@col[subs[[2]]]
              if (drop &&
                  (length(x@row) == 1 || length(x@col) == 1)) {
                  if (length(x@row) == 1) {
                      if (length(x@col) == 1)
                          as(x@row[1]+n*x@col[1], 'positiveIndex')
                      else as.integer(x@row[1])-1+n*x@col
                  } else x@row+n*(as.integer(x@col[1])-1)
              } else {
                  x@Names <- NULL
                  x
              }
          }
      })

setAs("matrixIndex", "vectorIndex",
      function(from, to)
  {
      ans <- .Call('matrixToVectorIndex', from@row, length(from@row),
                   from@col, length(from@col), from@origdim,
                   new("allIndex"), length(from),
                   PACKAGE='externalVector')
      if (!is.null(names(from)))
          names(ans) <- from
      ans
  })

setMethod("Subset",
          signature(i="matrixIndex"),
          function (x, i)
      {
          dim(x) <- i@origdim
          Subset2(x, i@row, i@col)
      })
